package cn.bavelee.achartengineexamples;

import android.graphics.Color;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.FrameLayout;

import org.achartengine.ChartFactory;
import org.achartengine.chart.PointStyle;
import org.achartengine.model.XYMultipleSeriesDataset;
import org.achartengine.model.XYSeries;
import org.achartengine.renderer.XYMultipleSeriesRenderer;
import org.achartengine.renderer.XYSeriesRenderer;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;

public class LineChartActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_chart);
        FrameLayout frameLayout = findViewById(R.id.frameLayout);

        //存放每个系列的值
        //生成10个随机的double
        List<Double> dataList = Utils.getRandomDataList();
        //存放每个系列的颜色
        int color = Color.BLACK;
        //存放每个系列的标题
        String seriesName = "系列1";

        //添加到布局
        frameLayout.addView(createLineChart(dataList, color, seriesName));
    }

    private View createLineChart(List<Double> dataList, int color, String seriesName) {
        //存放渲染器集合
        XYMultipleSeriesRenderer renderer = new XYMultipleSeriesRenderer();
        //存放数据集合，double数据
        XYMultipleSeriesDataset dataSet = new XYMultipleSeriesDataset();
        //单个渲染器
        XYSeriesRenderer r1 = new XYSeriesRenderer();
        //折现颜色(前景色)
        r1.setColor(Color.BLUE);
        //显示折现上的数值,模拟器上可能会有数值不显示
        r1.setDisplayChartValues(true);
        //数值文本大小
        r1.setChartValuesTextSize(25f);
        //线条宽度
        r1.setLineWidth(3f);
        //折线点大小
        r1.setPointStyle(PointStyle.CIRCLE);
        r1.setFillPoints(true);
        r1.setPointStrokeWidth(15f);

        //单个数据集
        XYSeries s1 = new XYSeries(seriesName);

        for (int i = 0; i < dataList.size(); i++) {
            //把数据放进数据系列对应(x, y)轴
            s1.add(i, dataList.get(i));
            //添加自定义标题，需要设hixLabels(0)
            renderer.addXTextLabel(i, "数据" + i);
        }

        //设置x轴起始值和结束值,比临界值大一点可以更好的展示图表数据
        renderer.setXAxisMin(-1);
        renderer.setXAxisMax(dataList.size() + 1);

        //获取数据中的最大最小值，用于决定y轴的起始值和结束值
        double max = Utils.maxInList(dataList);
        double min = Utils.minInList(dataList);
        //最大的和最小的值，比当前数值大10%…可以更好的展示图标数据
        renderer.setYAxisMax(max + max * 0.1);
        renderer.setYAxisMin(min - min * 0.1);
        //设置x,y轴的刻度数量
        renderer.setYLabels(8);
        renderer.setXLabels(0);

        //显示图例
        renderer.setShowLegend(true);
        //图例文本大小
        renderer.setLegendTextSize(25f);
        //设置不允许拖动
        renderer.setPanEnabled(false);
        //设置不允许缩放
        renderer.setZoomEnabled(false);
        //文本角度
        renderer.setXLabelsAngle(90);

        //设置背景色，两个方法必须一起调用
        renderer.setBackgroundColor(Color.WHITE);
        renderer.setApplyBackgroundColor(true);
        //边距颜色，默认是黑色
        renderer.setMarginsColor(Color.WHITE);
        //四周边距，对应上左下右,要么不填要么就填四个值
        renderer.setMargins(new int[]{50, 50, 50, 50});
        //文本大小
        renderer.setLabelsTextSize(25f);

        //添加渲染器和数据集到集合，两者数量必须相等
        renderer.addSeriesRenderer(r1);
        dataSet.addSeries(s1);

        return ChartFactory.getLineChartView(this, dataSet, renderer);
    }

}

